#!/bin/bash
#
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://libmpeg2.sourceforge.net/files/mpeg2dec-0.5.1.tar.gz
# last revised     : 30/08/08

softname='mpeg2dec'
softnamesrc='libmpeg2'
softversion='0.5.1'
packageversion='54.1'

arch='i486'
cpu='i686'

prefix=/usr

#
# log
#
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softnamesrc-$softversion.tar.gz"
src="$buildir/$softnamesrc-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://libmpeg2.sourceforge.net/files/$softnamesrc-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/$prefix/man
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: MPEG-2 video stream decoder
$softname: 
$softname: libmpeg2 is a free library for decoding mpeg-2 and mpeg-1 video 
$softname: streams. 
$softname: 
$softname:  
$softname: 
$softname: 
$softname: 
$softname: 
$softname:
EOF

#
# check if source is present
#
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
cd $buildir
tar zxvf $srcpkg
cd $src

# configure the package and install it to the target directory

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --sysconfdir=/etc \
      --enable-shared \
      --disable-static \
      --mandir=/usr/man \
      --program-prefix="" \
      --program-suffix="" \

    make
    make install DESTDIR=$dest
    
# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS ChangeLog CodingStyle COPYING INSTALL NEWS README TODO \
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress Man and info Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

( cd $dest/$prefix/info
  find . -name "*.*" | xargs gzip -9
)

# put the ZenWalk build in the right directory
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5

#dep file
echo -e "alsa-lib,cxxlibs,gcc,xcb,xorg-libs" > $package.dep

#
# erase source
#
rm -rf $src
rm -rf $dest

#
# generate source file
#
echo http://users.zenwalk.org/user-accounts/bip/ISO/xap/mpeg2dec/source/build-mpeg2dec.sh > $package.src
echo $source >>$package.src

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
